/********************************************************************
 * Job Ticket API (JTAPI) fsgjt.h                                         
 *  
 * Copyright (c) 2004 High North Inc.                                                                  
 * Copyright (c) 2004 International Business Machines Corp.
 * Copyright (c) 2004 Seiko-Epson, Inc.
 * Copyright (c) 2004 Till Kamppeter.  
 * Copyright (c) 2004 Free Standards Group.                   
 *                                                                    
 *                    Common Public License - v 1.0 
 * THE ACCOMPANYING PROGRAM IS PROVIDED UNDER THE TERMS OF THIS 
 * COMMON PUBLIC LICENSE ("AGREEMENT"). ANY USE, REPRODUCTION OR 
 * DISTRIBUTION OF THE PROGRAM CONSTITUTES RECIPIENT'S ACCEPTANCE 
 * OF THIS AGREEMENT.   
 *
 * The Common Public License in its entirety is located in 
 * fsgjt_cpl.h and applies to the contents of this file. 
 *******************************************************************/

#ifndef FSGJT_JOB_H
#define FSGJT_JOB_H

#include <fsgjt.h>

/* Defined constant to uniquely identify this type of JTAPI object */
#define FSGJT_JOB_OBJECT           "JJOB"

/************************************************************
 * Job attributes
 ***********************************************************/
/* Single value where type is char* */
#define FSGJT_JOB_COMMENT                    "job-comment"

/* Single value where type is fsgjt_int_32_t (IntegerType) */
#define FSGJT_JOB_COPIES                     "job-copies"

/* Multiple values where type is fsgjt_object_t (Destination) */
#define FSGJT_JOB_DESTINATIONS               "job-destinations"

/* Multiple values where type is fsgjt_object_t (Document) */
#define FSGJT_JOB_DOCUMENTS                  "job-documents"

/* Single value where type is fsgjt_mime_type_t (MimeType) */
#define FSGJT_JOB_DOCUMENT_FORMAT            "job-document-format"

/* Single value where type is fsgjt_object_t (Media) */
#define FSGJT_JOB_MEDIA                      "job-media"

/* Single value where type is char* */
#define FSGJT_JOB_NAME                       "job-name"

/* Single value where type is fsgjt_rotation_t (RotationEnum) */
#define FSGJT_JOB_ROTATION                   "job-rotation"

/* Single value where type is fsgjt_print_quality_t 
   (PrintQualityEnum) */
#define FSGJT_JOB_PRINT_QUALITY              "job-print-quality"

/* Single value where type is fsgjt_sides_t (SidesEnum) */
#define FSGJT_JOB_SIDES                      "job-sides"

/* Single value where type is fsgjt_object_t (Stitching) */
#define FSGJT_JOB_STITCHING                  "job-stitching"

/************************************************************
 * fsgjtNewJob - Creates a Job without providing a Document.
 *
 * param (output) fsgjt_object_t* job - Pointer to job to be 
 *      created
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewJob(
               fsgjt_object_t* job);

/************************************************************
 * fsgjtNewJobFromDocument - Creates a Job containing the 
 * provided Document.
 *
 * param (output) fsgjt_object_t* job - Pointer to job to be 
 *      created
 * param (input) fsgjt_object_t document - Document to be 
 *      contained in this job
 *
 * return fsgjt_return_code_t
 ***********************************************************/
fsgjt_return_code_t fsgjtNewJobFromDocument(
               fsgjt_object_t* job, 
               fsgjt_object_t document);       

#endif /* FSGJT_JOB_H */
